# -*- coding: utf-8 -*-

"""'summary' subcommand """

# ----------------------- Imports --------------------------------
import os
from pathlib import Path
import datetime
import csv

# My modules
import config
from modules.utils import verbose

#--------------------------Functions------------------------------
def summary_run(data_dir, res_dirs):
    """
    'summary' subcommand
    :param data_dir: data directory
    :param res_dirs: list of results directories names (in 'easYPipe' folder)
    :return: log file
    """

    date = datetime.datetime.now().strftime("%Y-%m-%d_%H%M%S")

    """Folder where we work"""
    work_dir = Path.cwd()
    """The existence of following path (created with 'prep' subcommand) has been checked in easypipe"""
    phenix_dir = work_dir.joinpath('easYPipe')

    """Create a log file"""
    nom_log = "summary_RESULTS_easYPipe_" + date + ".log"
    summary_log = verbose.log_start(phenix_dir, 'logs-summary-RESULTS', nom_log, verbose.easypipe_logo)

    # liste les fichiers résultats dans le(s) dossier(s) RESULTS_...
    for dir in res_dirs:
        verbose.print_and_write(verbose.cadre_text(config.motif, config.nb_motifs,
                                                   "Result directory: " + Path(dir).name), summary_log)
        res_files = [f for f in phenix_dir.joinpath(dir).iterdir() if f.is_file() and f.name.startswith('RESULTS')
                     and f.suffix.lower() == '.csv']    # ne prend pas les .xlsx si on en a créé
        verbose.print_and_write("List of RESULT csv files:", summary_log)
        for file in res_files:
            verbose.print_and_write(file.name, summary_log)
        verbose.print_and_write(verbose.chaine_xfois(config.sub_motif, config.nb_motifs), summary_log)

        # récupère le header
        with open(res_files[0], newline='') as csvfile:
            mtz_csv_reader = csv.DictReader(csvfile)
            header = mtz_csv_reader.fieldnames  # récupère le header
        verbose.print_and_write("Header: " + ' / '.join(header), summary_log)
        verbose.print_and_write(verbose.chaine_xfois(config.sub_motif, config.nb_motifs), summary_log)

        rows_all_files = []  # liste de liste de cellules (ligne du csv)
        for file in res_files:
            verbose.print_and_write("File: " + file.name, summary_log)
            with open(file, newline='') as csvfile:
                mtz_csv_reader = csv.DictReader(csvfile)
                for row in mtz_csv_reader:
                    # vérif si treated = 'yes'
                    if row['treated'] == 'yes':
                        rows_all_files.append(row)

        # enlever les doublons de la liste
        # Set est une structure de données non ordonnée qui ne contient que des éléments uniques
        #rows_all_files = list(set(rows_all_files))  # ne marche pas car liste de listes
        rows_all_files_nodouble = []
        for l in rows_all_files:
            if l not in rows_all_files_nodouble:
                rows_all_files_nodouble.append(l)

                # trier par dataset, ...
        # commencer par dernier à trier et finir par l'attribut majeur afin que l'ordre soit correct après plusieurs tris
        # nécessaire car certains sont en reverse
        rows_all_files_nodouble.sort(key=lambda row: row['Nb of ligands found'] or "", reverse=True)
        rows_all_files_nodouble.sort(key=lambda row: row['Completeness'] or "", reverse=True)
        rows_all_files_nodouble.sort(key=lambda row: row['Ligand'] or "") # or "": gérer cellules avec None Type
        # TypeError: '<' not supported between instances of 'NoneType' and 'NoneType'
        rows_all_files_nodouble.sort(key=lambda row: row['mode'], reverse=True)
        rows_all_files_nodouble.sort(key=lambda row: row['ligand search'], reverse=True)
        rows_all_files_nodouble.sort(key=lambda row: row['SUCCESS'], reverse=True)
        rows_all_files_nodouble.sort(key=lambda row: row['dataset'])


        verbose.print_and_write(verbose.chaine_xfois(config.sub_motif, config.nb_motifs), summary_log)

        # Copier la liste dans le fichier summary
        summary = phenix_dir.joinpath(dir, 'SUMMARY_' + dir + '.csv')
        verbose.print_and_write("Summary file created: " + summary.name + " in " + dir + " folder", summary_log)
        with open(summary, 'w', newline='') as csvfile_sum:
            csv_writer = csv.writer(csvfile_sum, quoting=csv.QUOTE_MINIMAL)
            csv_writer.writerow(header)
            for row in rows_all_files_nodouble:
                csv_writer.writerow(row.values())

    verbose.print_and_write("\nDone ...", summary_log)
    return summary_log


