# -*- coding: utf-8 -*-

"""Tools to print in terminal and in log files"""

easypipe_logo = \
"""
                         ______
                   \  /  |     /
__    __     ___    \/   |_____/  -  ___   __
|_|  /  \    \__    /    |        |  |__/  |_|
|__  \__/|__  __/  /     |        |  |     |__

"""

easyget_logo = \
"""
                         ______
                   \  /  |     
__    __     ___    \/   |   __   __   |
|_|  /  \    \__    /    |     |  |_|  |--
|__  \__/|__  __/  /     |_____/  |__  |_  

"""

#-------------------------- Imports ------------------------------------------------------------------------------------
import sys
from pathlib import Path
# My modules
import config


#---------------------------Functions ----------------------------------------------------------------------------------
def print_and_write(text, nomfichier):
    """
    At the same time writes a text in the terminal and also in a file.
    """
    with open(nomfichier,'a') as f:
        f.write("\n" + text)
    print(text)

def chaine_xfois(sigle, nb_de_fois):
    """
    :param sigle: acronym
    :param nb_de_fois: number of time to repeat acronym
    :return : a string of characters with a certain number of times an acronym.
    """
    ligne = sigle * nb_de_fois
    return ligne

def chaine_xfois_text(sigle, nb_de_fois, text):
    """
    :param sigle: acronym
    :param nb_de_fois: number of time to repeat acronym, text included
    :param text: text to insert in the middle
    :return : a string of characters with a certain number of times an acronym
     and inserted in the middle the text, total length = nb_of_times
    """
    if nb_de_fois - len(text) >= 2:					# cas où la longueur de la chaîne ne dépasse pas le nb de sigles !!
        demi_nb = (nb_de_fois - len(text) -2) // 2				# // division entière
    else:
        demi_nb = 1
    ligne = sigle * demi_nb + " " + text + " " + sigle * demi_nb
    while len(ligne) < nb_de_fois:
        ligne += sigle
    return ligne

def cadre_text(sigle, nb_de_fois, text):
    """
    To create a title in a frame.
    :return: formatted string
    """
    text_OK = text
    cadre = '\n' + sigle * nb_de_fois + '\n'
    nb_blanc = (nb_de_fois - len(text) - 4) // 2
    if nb_blanc < 1:			# cas où la longueur de la chaîne dépasse le nb de sigles + 6 !!
        cadre = cadre + text + '\n'
    else:
        blanc = nb_blanc * ' '
        cadre = cadre + sigle * 2 + blanc + text + blanc + (' ' if len(text) %2 != 0 else '') + sigle * 2 + '\n'
    cadre = cadre + sigle * nb_de_fois
    return cadre

def log_start(dir, log_dir, nom_log, logo):
    """
    Create a log file with starting informations
    :param dir: folder where 'logs' folder will be created (with path)
    :param log_dir: name of folder where log file will be
    :param nom_log: name of log file
    :return: log file with path
    """
    dir.joinpath(log_dir).mkdir(exist_ok=True)
    log = str(dir.joinpath(log_dir, nom_log))  # dans sous-dossier logs
    print_and_write(logo, log)
    print_and_write(
        cadre_text(config.motif, config.nb_motifs, "Starting informations"), log)
    print_and_write("Command: " + Path(sys.argv[0]).name + " " + " ".join(sys.argv[1:]), log)
    print_and_write(chaine_xfois(config.sub_motif, config.nb_motifs), log)
    return log

def seconds_to_hhmmss(seconds):
    """
    Transform time in seconds in readable hours:minutes:seconds
    :return: tuple hours, minutes, seconds
    """
    hours, seconds = divmod(seconds, 3600)
    minutes, seconds = divmod(seconds, 60)
    return hours, minutes, seconds

def question_y_n(text):
  """
  Ask a question and continue if the answer is yes.
  :param text: question to display
  """
  question = True
  while question:
    choice = input(text + " (y/n): ")
    if choice.lower() in ('y', 'n'):
      question = False
      if choice.lower() == ('y'):
        pass
      else:
        print("\n", chaine_xfois(config.sub_motif, config.nb_motifs), "\n")
        sys.exit("Program stopped by user ...")